@@ -1,3 +1,4 @@
+from __future__ import print_function
 import cmor
 import numpy
 import sys
@@ -11,7 +12,7 @@ try:
     cdms2.setNetcdfDeflateFlag(0)
     cdms2.setNetcdfDeflateLevelFlag(0)
 except BaseException:
-    print "This test code needs a recent cdms2 interface for i/0"
+    print("This test code needs a recent cdms2 interface for i/0")
     sys.exit()
 
 if len(sys.argv) > 1:
@@ -48,7 +49,7 @@ cmor.dataset_json("Test/CMOR_input_example.json")
 
 tables = []
 tables.append(cmor.load_table("mytable"))
-print 'Tables ids:', tables
+print('Tables ids:', tables)
 
 
 # read in data, just one slice
@@ -96,7 +97,7 @@ mincdms = 1000
 c0 = st
 s2 = s * 1
 sh = list(s.shape)
-print 'shape:', sh
+print('shape:', sh)
 sh.insert(0, 1)
 s2 = MV2.reshape(s2, sh)
 s2.setAxis(1, s.getLatitude())
@@ -135,14 +136,14 @@ import os
 ltime = cdtime.reltime(ntimes - 1, 'month since 1980').tocomp()
 #lcmor = os.stat("CMIP6/CMIP/CSIRO-BOM/NICAM/piControl/r1i1p1f1/Amon/tas/gn/v%s/tas_Amon_piControl_NICAM_r1i1p1f1_gn_198001-%i%.2i.nc" % (today,ltime.year,ltime.month))[6]
 lcmor = os.stat(
-    "CMIP6/CMIP6/ISMIP6/PCMDI/PCMDI-test-1-0/piControl-withism/r11i1p1f1/Amon/tas/gr/v%s/tas_Amon_PCMDI-test-1-0_piControl-withism_r11i1p1f1_gr_198001-%i%.2i.nc" %
+    "CMIP6/CMIP6/ISMIP6/PCMDI/PCMDI-test-1-0/piControl-withism/r3i1p1f1/Amon/tas/gn/v%s/tas_Amon_PCMDI-test-1-0_piControl-withism_r3i1p1f1_gn_198001-%i%.2i.nc" %
     (today, ltime.year, ltime.month))[6]
-print 'level:', level, "shuffle:", shuffle
-print 'total cmor:', totcmor, mincmor, totcmor / ntimes, maxcmor, lcmor
+print('level:', level, "shuffle:", shuffle)
+print('total cmor:', totcmor, mincmor, totcmor / ntimes, maxcmor, lcmor)
 lcdms = os.stat("Test/crap.nc")[6]
-print 'total cdms:', totcdms, mincdms, totcdms / ntimes, maxcdms, lcdms
-print 'Size diff:', float(lcmor) / float(lcdms)
-print 'speed diff:', totcmor / totcdms
+print('total cdms:', totcdms, mincdms, totcdms / ntimes, maxcdms, lcdms)
+print('Size diff:', float(lcmor) / float(lcdms))
+print('speed diff:', totcmor / totcdms)
 
 if os.path.exists("summary.txt"):
     f = open("summary.txt")
@@ -157,7 +158,7 @@ dic[(level, shuffle)] = (float(lcmor) / float(lcdms), totcmor / totcdms)
 for i in range(10):
     a = dic.get((i, 0), "N/A")
     b = dic.get((i, 1), "N/A")
-    print 'Level: ', i, "no suffle:", a, "shuffle", b
+    print('Level: ', i, "no suffle:", a, "shuffle", b)
 f = open("summary.txt", "w")
 f.write(repr(dic))
 f.close()
