@@ -233,7 +233,7 @@ PROGRAM mip_contribution
   ! Define dataset as output from the INM model 
 
   print*, 'calling cmor_dataset'
-  error_flag = cmor_dataset_json("Test/common_user_input.json")
+  error_flag = cmor_dataset_json("Test/CMOR_input_example.json")
   
   print*, 'returned from cmor_dataset'
 
