@@ -209,7 +209,7 @@ PROGRAM mip_contribution
   !   all CF-netCDF files written as part of this dataset.
 
   print*, 'calling cmor_dataset'
-  error_flag = cmor_dataset_json("Test/common_user_input.json")
+  error_flag = cmor_dataset_json("Test/CMOR_input_example.json")
   print*, 'returned from cmor_dataset'
 
   print*, 'calling cmor_set_cur_dataset_attribute'
