@@ -1,4 +1,5 @@
 #****** Conflict with 'orog' in formula terms *****
+from __future__ import print_function
 import cmor
 import numpy
 
@@ -92,7 +93,7 @@ if table_entry == 'hybrid_height':
         units='m',
         zfactor_values=data2d)
 else:
-    print 'yep working case'
+    print('yep working case')
     ilev = cmor.axis(
         table_entry='standard_sigma',
         units='1',
@@ -128,7 +129,7 @@ else:
         axis_ids=numpy.array((ilon, ilat, itim)),
         units='Pa')
 
-print "ILEV is:", ilev
+print("ILEV is:", ilev)
 var3d_ids = cmor.variable(
     table_entry='concdust',
     units='kg m-3',
