@@ -1,4 +1,4 @@
-export CFLAGS="-Wall -g -m64 -pipe -O2  -fPIC"
+export CFLAGS="-Wall -g -m64 -pipe -O2 -fPIC ${CFLAGS}"
 export CXXLAGS="${CFLAGS}"
 export CPPFLAGS="-I${PREFIX}/include"
 export LDFLAGS="-L${PREFIX}/lib"
@@ -10,6 +10,13 @@ if [[ ${CONDA_LST}'y' == *'openmpi'* ]]; then
     export DYLD_FALLBACK_LIBRARY_PATH=${PREFIX}/lib
 fi
 
+if [[ `uname` == "Linux" ]]; then
+    export LDSHARED_FLAGS="-shared -pthread"
+else
+    # For OSX builds, reset the include and linker root path for clang
+    export CFLAGS="-Wl,-syslibroot / -isysroot / ${CFLAGS}"
+    export LDSHARED_FLAGS="-bundle -undefined dynamic_lookup"
+fi
 
 ./configure \
     --with-python=${PREFIX}   \
@@ -18,7 +25,7 @@ fi
     --with-netcdf=${PREFIX} \
     --with-libjson-c=${PREFIX} \
     --prefix=${PREFIX}
-make
+make 
 make install
 # Make sure CMOR UDNITS2 env is still present in the package
 ACTIVATE_DIR=$PREFIX/etc/conda/activate.d
